package csir.user.par;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Version;

import org.jboss.seam.annotations.Name;

/**
 * Entity bean containing the Role. For JAAS it is required to have a column with the name P_GROUP which always return "Roles"
 * See the files: build/config/JAASExample-login-config.xml as well as build/config/db-scripts/import.sql
 * 
 * @author  <a href="mailto:louis.coetzee@csir.co.za">Louis Coetzee</a>
 *
 */
@Entity
@Name("portalRole")
@Table(name="portal_role")
public class PortalRole implements Serializable {

	private static final long serialVersionUID = -7225746552938049404L;
	private Integer id;
	private Integer version;
	private String roleName;
	private String roleDescription;
	private String pGroup; //jaas wants this. Note the column name in the database

	public PortalRole() {
	}

	@Id  @GeneratedValue(strategy=GenerationType.AUTO)
	@Column(name="portalrole_id")
	public Integer getId() {
		return id;
	}

	public void setId(Integer id) {
		this.id = id;
	}

	public String getRoleDescription() {
		return roleDescription;
	}

	public void setRoleDescription(String roleDescription) {
		this.roleDescription = roleDescription;
	}

	public String getRoleName() {
		return roleName;
	}

	public void setRoleName(String roleName) {
		this.roleName = roleName;
	}

	@Version
	public Integer getVersion() {
		return version;
	}

	public void setVersion(Integer version) {
		this.version = version;
	}
	
	@Column(name="P_GROUP")
	public String getPGroup() {
		return pGroup;
	}

	public void setPGroup(String group) {
		pGroup = group;
	}
	
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append(roleName + "-->" +roleDescription);
		return sb.toString();
	}
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if ((obj == null) || (obj.getClass() != this.getClass()))
			return false;
		// object must be PortalRole at this point
		PortalRole pos = (PortalRole) obj;
		return (id == pos.id);				
	}

	public int hashCode() {
		return id.hashCode();
	}
}
