package csir.user.seam;

import org.jboss.jmx.adaptor.rmi.RMIAdaptor;
import javax.naming.InitialContext;
import javax.rmi.PortableRemoteObject;
import javax.management.ObjectName;

import org.apache.log4j.Logger;

/**
 * Utitily class to flush the JAAS cache if roles were removed or added to a user
 * 
 * @see <a href= "http://wiki.jboss.org/wiki/Wiki.jsp?page=CachingLoginCredentials">Flush Cache</>
 * <a href="mailto:louis.coetzee@csir.co.za">Louis Coetzee</a>
 * @author lcoetzee
 *
 */
public class FlushJaasCache {

	static final Logger logger = Logger.getLogger(FlushJaasCache.class);

	
	public FlushJaasCache() {
		logger.info("FlushJaasCache started");
	}

	static void flushJaasAuthenticationCache() throws Exception {
		String connectorName = "jmx/invoker/RMIAdaptor";
		logger.info("Using " + connectorName + " to flush cache");

		Object ref = new InitialContext().lookup(connectorName);
		logger.info("Got ref to context");

		RMIAdaptor server = (RMIAdaptor) PortableRemoteObject.narrow(ref,
				RMIAdaptor.class);
		logger.info("Got RMIAdaptor");

		ObjectName jaasMgr = new ObjectName(
				"jboss.security:service=JaasSecurityManager");
		Object[] params = { "jaasExampleEntityManager" };
		String[] signature = { "java.lang.String" };
		server.invoke(jaasMgr, "flushAuthenticationCache", params, signature);
		logger.info("And  flushed the cache");
	}

}
